#ifndef _CC1100_H_
#define _CC1100_H_
#include "public.h"

#define CC1100_PIN_1100
#define CC1100_DATA_LEN 32

//---------------------- CC1100 STROBE, CONTROL AND STATUS REGSITER-------------- 
#define CCxxx0_IOCFG2       0x00         // GDO2 output pin configuration
#define CCxxx0_IOCFG1       0x01         // GDO1 output pin configuration
#define CCxxx0_IOCFG0       0x02         // GDO0 output pin configuration
#define CCxxx0_FIFOTHR      0x03         // RX FIFO and TX FIFO thresholds
#define CCxxx0_SYNC1        0x04         // Sync word, high uint8
#define CCxxx0_SYNC0        0x05         // Sync  word, low uint8
#define CCxxx0_PKTLEN       0x06        // Packet length
#define CCxxx0_PKTCTRL1     0x07       // Packet automation control
#define CCxxx0_PKTCTRL0     0x08        // Packet automation control
#define CCxxx0_ADDR         0x09          // Device address
#define CCxxx0_CHANNR       0x0A        // Channel number
#define CCxxx0_FSCTRL1      0x0B        // Frequency synthesizer control
#define CCxxx0_FSCTRL0      0x0C        // Frequency synthesizer control
#define CCxxx0_FREQ2        0x0D          // Frequency control word, high uint8
#define CCxxx0_FREQ1        0x0E          // Frequency control word, middle uint8
#define CCxxx0_FREQ0        0x0F          // Frequency control word, low uint8
#define CCxxx0_MDMCFG4      0x10        // Modem configuration
#define CCxxx0_MDMCFG3      0x11        // Modem configuration
#define CCxxx0_MDMCFG2      0x12        // Modem configuration
#define CCxxx0_MDMCFG1      0x13        // Modem configuration
#define CCxxx0_MDMCFG0      0x14        // Modem configuration
#define CCxxx0_DEVIATN      0x15         // Modem deviation setting
#define CCxxx0_MCSM2        0x16          // Main Radio Control State Machine configuration
#define CCxxx0_MCSM1        0x17          // Main Radio Control State Machine configuration
#define CCxxx0_MCSM0        0x18          // Main Radio Control State Machine configuration
#define CCxxx0_FOCCFG       0x19          // Frequency Offset Compensation configuration
#define CCxxx0_BSCFG        0x1A            // Bit Synchronization configuration
#define CCxxx0_AGCCTRL2     0x1B        // AGC control
#define CCxxx0_AGCCTRL1     0x1C        // AGC control
#define CCxxx0_AGCCTRL0     0x1D        // AGC control
#define CCxxx0_WOREVT1      0x1E        // High uint8 Event 0 timeout
#define CCxxx0_WOREVT0      0x1F        // Low uint8 Event 0 timeout
#define CCxxx0_WORCTRL      0x20        // Wake On Radio control
#define CCxxx0_FREND1       0x21        // Front end RX configuration
#define CCxxx0_FREND0       0x22        // Front end TX configuration
#define CCxxx0_FSCAL3       0x23        // Frequency synthesizer calibration
#define CCxxx0_FSCAL2       0x24        // Frequency synthesizer calibration
#define CCxxx0_FSCAL1       0x25        // Frequency synthesizer calibration
#define CCxxx0_FSCAL0       0x26        // Frequency synthesizer calibration
#define CCxxx0_RCCTRL1      0x27        // RC oscillator configuration
#define CCxxx0_RCCTRL0      0x28        // RC oscillator configuration
#define CCxxx0_FSTEST       0x29        // Frequency synthesizer calibration control
#define CCxxx0_PTEST        0x2A        // Production test
#define CCxxx0_AGCTEST      0x2B        // AGC test
#define CCxxx0_TEST2        0x2C        // Various test settings
#define CCxxx0_TEST1        0x2D        // Various test settings
#define CCxxx0_TEST0        0x2E        // Various test settings

#define CCxxx0_PARTNUM      0x30
#define CCxxx0_VERSION      0x31
#define CCxxx0_FREQEST      0x32
#define CCxxx0_LQI          0x33
#define CCxxx0_RSSI         0x34
#define CCxxx0_MARCSTATE    0x35
#define CCxxx0_WORTIME1     0x36
#define CCxxx0_WORTIME0     0x37
#define CCxxx0_PKTSTATUS    0x38
#define CCxxx0_VCO_VC_DAC   0x39
#define CCxxx0_TXBYTES      0x3A
#define CCxxx0_RXBYTES      0x3B
#define CCxxx0_PATABLE      0x3E
#define CCxxx0_TXFIFO       0x3F
#define CCxxx0_RXFIFO       0x3F

//  CMD
#define CCxxx0_SRES         0x30            // Reset 
#define CCxxx0_SFSTXON      0x31        // Enable and calibrate frequency synthesizer (if MCSM0.FS_AUTOCAL=1).   If in RX/TX: Go to a wait state where only the synthesizer is  running (for quick RX / TX turnaround).
#define CCxxx0_SXOFF        0x32        // Turn off crystal oscillator.
#define CCxxx0_SCAL         0x33        // Calibrate frequency synthesizer and turn it off                                      // (enables quick start).
#define CCxxx0_SRX          0x34        // Enable RX. Perform calibration first if coming from IDLE and // MCSM0.FS_AUTOCAL=1.
#define CCxxx0_STX          0x35        // In IDLE state: Enable TX. Perform calibration first if // MCSM0.FS_AUTOCAL=1. If in RX state and CCA is enabled:  // Only go to TX if channel is clear.
#define CCxxx0_SIDLE        0x36        // Exit RX / TX, turn off frequency synthesizer and exit  // Wake-On-Radio mode if applicable.
#define CCxxx0_SAFC         0x37        // Perform AFC adjustment of the frequency synthesizer
#define CCxxx0_SWOR         0x38        // Start automatic RX polling sequence (Wake-on-Radio)
#define CCxxx0_SPWD         0x39        // Enter power down mode when CSn goes high.
#define CCxxx0_SFRX         0x3A        // Flush the RX FIFO buffer.
#define CCxxx0_SFTX         0x3B        // Flush the TX FIFO buffer.
#define CCxxx0_SWORRST      0x3C        // Reset real time clock.
#define CCxxx0_SNOP         0x3D        // No operation. May be used to pad strobe commands to two  // uint8s for simpler software.


#define 	WRITE_SINGLE    0x00						//д
#define 	WRITE_BURST     	0x40						//д
#define 	READ_SINGLE     	0x80						//ȡ
#define 	READ_BURST      	0xC0						//ȡ

typedef struct _CC1100_RF_SETTINGS_
{
	uint8 IOCFG2;    // GDO2 output pin configuration
	uint8 IOCFG1;
	uint8 IOCFG0;    // GDO0 output pin configuration
	uint8 FIFOTHR;
	uint8 SYNC1;
	uint8 SYNC0;
	uint8 PKTLEN;    // Packet length.
	uint8 PKTCTRL1;  // Packet automation control.
	uint8 PKTCTRL0;  // Packet automation control.
	uint8 ADDR;      // Device address.
	uint8 CHANNR;
		
	uint8 FSCTRL1;   // Frequency synthesizer control.
	uint8 FSCTRL0;   // Frequency synthesizer control.
	uint8 FREQ2;     // Frequency control word, high uint8.
	uint8 FREQ1;     // Frequency control word, middle uint8.
	uint8 FREQ0;     // Frequency control word, low uint8.
	
	uint8 MDMCFG4;   // Modem configuration.
	uint8 MDMCFG3;   // Modem configuration.
	uint8 MDMCFG2;   // Modem configuration.
	uint8 MDMCFG1;   // Modem configuration.
	uint8 MDMCFG0;   // Modem configuration.
	
	uint8 DEVIATN;   // Modem deviation setting (when FSK modulation is enabled).
	uint8 MCSM2;     // Main Radio Control State Machine configuration.
	uint8 MCSM1;     // Main Radio Control State Machine configuration.	
	uint8 MCSM0;     // Main Radio Control State Machine configuration.
	uint8 FOCCFG;    // Frequency Offset Compensation Configuration.
	uint8 BSCFG;     // Bit synchronization Configuration.
	uint8 AGCCTRL2 ;
	uint8 AGCCTRL1 ;
	uint8 AGCCTRL0 ;
	uint8 WOREVT1;
	uint8 WOREVT0;	
	uint8 WORCTRL;
	uint8 FREND1;    // Front end RX configuration.
	uint8 FREND0;    // Front end RX configuration.
	uint8 FSCAL3;    // Frequency synthesizer calibration.
	uint8 FSCAL2;    // Frequency synthesizer calibration.
	uint8 FSCAL1;    // Frequency synthesizer calibration.
	uint8 FSCAL0;    // Frequency synthesizer calibration.
	uint8 RCCTRL1;
	uint8  RCCTRL0;
	uint8 FSTEST;    // Frequency synthesizer calibration control
	uint8 PTEST;
	uint8 AGCTEST;
	uint8 TEST2;     // Various test settings.
	uint8 TEST1;     // Various test settings.
	uint8 TEST0;     // Various test settings.

}CC1100_RF_SETTINGS;

//---------------------CC1100Ŷ------------------------
#ifdef CC1100_PIN_RFC
sbit 	GDO0       	=  P3^3;
sbit 	GDO2 	      =  P2^1;
sbit	MISO 	        =  P3^6;
sbit	MOSI		=  P3^5;
sbit	SCK			=  P3^7;
sbit	CSN			=  P2^2;
#endif

#ifdef CC1100_PIN_1100
sbit 	GDO0       	= P3^3;
sbit 	GDO2        	= P2^5;
sbit	MISO	        = P2^4;
sbit	MOSI		= P2^1;
sbit	SCK			= P2^3;
sbit	CSN			= P2^6;
#endif

#define MOSI_ON()    		MOSI = 1  
#define MOSI_OFF()  		MOSI = 0  
#define SCK_ON()    		SCK	= 1 
#define SCK_OFF()  		SCK	= 0
#define CSN_ON()    		CSN	= 1
#define CSN_OFF()  		CSN	= 0

//-------------------ԭ-----------------------
void CC1100_Init(void);
void CC1100_SetRxMode(void);
uint8 CC1100_RxPacket(void) ;
void CC1100_TxPacket(void);
void CC1100_WriteReg(uint8 addr, uint8 value) ;
uint8 CC1100_ReadReg(uint8 addr) ;
void CC1100_WriteBurstReg(uint8 addr, uint8 *buffer, uint8 count) ;
void CC1100_ReadBurstReg(uint8 addr, uint8 *buffer, uint8 count) ;
void CC1100_Command(uint8 cmd) ;
void CC1100_Write_RxADDR(void);
void CC1100_Write_TxADDR(void);

void SPI_Init(void);
uint8 SPI_Read(void);
void SPI_Write(uint8 txdata);

//--------------------- λڵ-----------------------------

#define UART_READ_BACK  		0x01         //ڻԣԴ

#define CC1100_READ_RXADDR     0x20
#define CC1100_READ_TXADDR     0x21
#define CC1100_WRITE_RXADDR  0x22
#define CC1100_WRITE_TXADDR  0x23

#define CC1100_READ_BUF32 	0x24
#define CC1100_READ_REG  		0x25
#define CC1100_WRITE_REG   	0x26
#define CC1100_WRITE_BUF32	0x27

#define CC1100_SET_RXMODE      0x28
#define CC1100_RX 			 0x29
#define CC1100_TX  			 0x2A

#define CC1100_CMD                0x2D
#define CC1100_INIT 			0x2E
#define CC1100_EXT             	0x2F

#endif

